/*  zomg/vorbis, a zsh module for extracting information from Ogg Vorbis files
    Copyright (C) 2005, 2006  Clint Adams

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */

#include <stdio.h>
#include <math.h>

#include <vorbis/vorbisfile.h>

#include "vorbis.mdh"
#include "vorbis.pro"

static char *nam="zomg/vorbis";

/**/
static int
bin_zomghelper_vorbis(char *nam, char **args, Options ops, UNUSED(int func))
{
    FILE *f;
    OggVorbis_File vf;
    double k;
    vorbis_comment *com;
    char **soc;
    char **oargs;
    int i=0, j=0;

    for (oargs = args; *args; i++, args++) {

	f = fopen(*args, "r");
	if (f==NULL) {
	    zwarnnam(nam, "unable to open file: %s", *args, 0);
	    j++;
	    continue;
	}
	printf("(Reading vorbis file: %s)\n", *args);

	ov_open(f, &vf, NULL, 0);

	k = ov_time_total(&vf,-1);

	com = ov_comment(&vf,-1);

	printf("ZOMGSECS: %d\n", (int)ceil(k));

	soc = com->user_comments;

	while(*(soc)) {
		printf("%s\n", *soc++);
	}
    }

    return !!j;
}

/*
 * boot_ is executed when the module is loaded.
 */

static struct builtin bintab[] = {
    BUILTIN("zomghelper_vorbis", 0, bin_zomghelper_vorbis, 0, -1, 0, "flags", NULL),
};

/**/
int
setup_(UNUSED(Module m))
{
    return 0;
}

/**/
int
boot_(Module m)
{
    return !(addbuiltins(m->nam, bintab, sizeof(bintab)/sizeof(*bintab)));
}

/**/
int
cleanup_(Module m)
{
    deletebuiltins(m->nam, bintab, sizeof(bintab)/sizeof(*bintab));
    return 0;
}

/**/
int
finish_(UNUSED(Module m))
{
    return 0;
}
